@@ -8,4 +8,4 @@ from .managers import *
 from .solcatcher_processing import *
 from .solcatcher_db_calls import *
 from .solcatcher_api_calls import *
-from .master_decoder import decode_event,initializeEnvironment
+from .master_decoder import *
